==> primefaces-14.0.0-sources.jar: org/primefaces/model/file/UploadedFiles.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2009-2024 PrimeTek Informatics
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.primefaces.model.file;

import java.io.Serializable;
import java.util.List;

public class UploadedFiles implements Serializable {

    private static final long serialVersionUID = 1L;

    private long size;
    private List<UploadedFile> files;

    public UploadedFiles() {
        // NOOP
    }

    public UploadedFiles(List<UploadedFile> files) {
        this.files = files;
        size = files.stream().mapToLong(UploadedFile::getSize).sum();
    }

    public List<UploadedFile> getFiles() {
        return files;
    }

    public long getSize() {
        return size;
    }

    public void write(String path) throws Exception {
        for (UploadedFile file : files) {
            file.write(path);
        }
    }
}

==> primefaces-15.0.4-sources.jar: org/primefaces/model/file/UploadedFiles.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2009-2025 PrimeTek Informatics
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.primefaces.model.file;

import java.io.File;
import java.io.Serializable;
import java.util.List;

public class UploadedFiles implements Serializable {

    private static final long serialVersionUID = 1L;

    private long size;
    private List<UploadedFile> files;

    public UploadedFiles() {
        // NOOP
    }

    public UploadedFiles(List<UploadedFile> files) {
        this.files = files;
        size = files.stream().mapToLong(UploadedFile::getSize).sum();
    }

    public List<UploadedFile> getFiles() {
        return files;
    }

    public long getSize() {
        return size;
    }

    public File write(String directoryPath) throws Exception {
        for (UploadedFile file : files) {
            file.write(directoryPath);
        }
        return null;
    }
}
